# Generated by ariadne-codegen
# Source: queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class BucketTabulatorTablesList(BaseModel):
    bucket_config: Optional["BucketTabulatorTablesListBucketConfig"] = Field(alias="bucketConfig")


class BucketTabulatorTablesListBucketConfig(BaseModel):
    tabulator_tables: List["BucketTabulatorTablesListBucketConfigTabulatorTables"] = Field(alias="tabulatorTables")


class BucketTabulatorTablesListBucketConfigTabulatorTables(BaseModel):
    name: str
    config: str


BucketTabulatorTablesList.model_rebuild()
BucketTabulatorTablesListBucketConfig.model_rebuild()
