# Generated by ariadne-codegen
# Source: queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .fragments import BucketConfigSelection


class BucketGet(BaseModel):
    bucket_config: Optional["BucketGetBucketConfig"] = Field(alias="bucketConfig")


class BucketGetBucketConfig(BucketConfigSelection):
    pass


BucketGet.model_rebuild()
