# Generated by ariadne-codegen
# Source: queries.graphql

from typing import Annotated, Literal, Optional, Union

from pydantic import Field

from .base_model import BaseModel
from .fragments import (
    InvalidInputSelection,
    OperationErrorSelection,
    SsoConfigSelection,
)


class SsoConfigSet(BaseModel):
    admin: "SsoConfigSetAdmin"


class SsoConfigSetAdmin(BaseModel):
    set_sso_config: Optional[
        Annotated[
            Union[
                "SsoConfigSetAdminSetSsoConfigSsoConfig",
                "SsoConfigSetAdminSetSsoConfigInvalidInput",
                "SsoConfigSetAdminSetSsoConfigOperationError",
            ],
            Field(discriminator="typename__"),
        ]
    ] = Field(alias="setSsoConfig")


class SsoConfigSetAdminSetSsoConfigSsoConfig(SsoConfigSelection):
    typename__: Literal["SsoConfig"] = Field(alias="__typename")


class SsoConfigSetAdminSetSsoConfigInvalidInput(InvalidInputSelection):
    typename__: Literal["InvalidInput"] = Field(alias="__typename")


class SsoConfigSetAdminSetSsoConfigOperationError(OperationErrorSelection):
    typename__: Literal["OperationError"] = Field(alias="__typename")


SsoConfigSet.model_rebuild()
SsoConfigSetAdmin.model_rebuild()
