# Generated by ariadne-codegen
# Source: queries.graphql

from typing import List

from pydantic import Field

from .base_model import BaseModel
from .fragments import BucketConfigSelection


class BucketsList(BaseModel):
    bucket_configs: List["BucketsListBucketConfigs"] = Field(alias="bucketConfigs")


class BucketsListBucketConfigs(BucketConfigSelection):
    pass


BucketsList.model_rebuild()
