# Generated by ariadne-codegen
# Source: queries.graphql

from typing import Literal, Union

from pydantic import Field

from .base_model import BaseModel


class BucketRemove(BaseModel):
    bucket_remove: Union[
        "BucketRemoveBucketRemoveBucketRemoveSuccess",
        "BucketRemoveBucketRemoveBucketNotFound",
        "BucketRemoveBucketRemoveIndexingInProgress",
    ] = Field(alias="bucketRemove", discriminator="typename__")


class BucketRemoveBucketRemoveBucketRemoveSuccess(BaseModel):
    typename__: Literal["BucketRemoveSuccess"] = Field(alias="__typename")


class BucketRemoveBucketRemoveBucketNotFound(BaseModel):
    typename__: Literal["BucketNotFound"] = Field(alias="__typename")


class BucketRemoveBucketRemoveIndexingInProgress(BaseModel):
    typename__: Literal["IndexingInProgress"] = Field(alias="__typename")


BucketRemove.model_rebuild()
