# Generated by ariadne-codegen
# Source: queries.graphql

from typing import List

from .base_model import BaseModel
from .fragments import UserSelection


class UsersList(BaseModel):
    admin: "UsersListAdmin"


class UsersListAdmin(BaseModel):
    user: "UsersListAdminUser"


class UsersListAdminUser(BaseModel):
    list: List["UsersListAdminUserList"]


class UsersListAdminUserList(UserSelection):
    pass


UsersList.model_rebuild()
UsersListAdmin.model_rebuild()
UsersListAdminUser.model_rebuild()
